==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/DeviceAssuranceChromeOSPlatform.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DeviceAssurance;
import com.okta.sdk.resource.model.DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders;
import com.okta.sdk.resource.model.LinksSelf;
import com.okta.sdk.resource.model.Platform;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DeviceAssuranceChromeOSPlatform
 */
@JsonPropertyOrder({ DeviceAssuranceChromeOSPlatform.JSON_PROPERTY_THIRD_PARTY_SIGNAL_PROVIDERS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "platform", visible = true, defaultImpl = DeviceAssuranceChromeOSPlatform.class)

public class DeviceAssuranceChromeOSPlatform extends DeviceAssurance implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_THIRD_PARTY_SIGNAL_PROVIDERS = "thirdPartySignalProviders";
    private DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders thirdPartySignalProviders;

    public DeviceAssuranceChromeOSPlatform() {
    }

    /*
     * @JsonCreator public DeviceAssuranceChromeOSPlatform(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED_BY) String createdBy,
     *
     * @JsonProperty(JSON_PROPERTY_CREATED_DATE) String createdDate,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATE) String lastUpdate,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED_BY) String lastUpdatedBy ) { this(); this.createdBy = createdBy;
     * this.createdDate = createdDate; this.id = id; this.lastUpdate = lastUpdate; this.lastUpdatedBy = lastUpdatedBy; }
     */

    public DeviceAssuranceChromeOSPlatform thirdPartySignalProviders(
            DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders thirdPartySignalProviders) {

        this.thirdPartySignalProviders = thirdPartySignalProviders;
        return this;
    }

    /**
     * Get thirdPartySignalProviders
     *
     * @return thirdPartySignalProviders
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_THIRD_PARTY_SIGNAL_PROVIDERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders getThirdPartySignalProviders() {
        return thirdPartySignalProviders;
    }

    @JsonProperty(JSON_PROPERTY_THIRD_PARTY_SIGNAL_PROVIDERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setThirdPartySignalProviders(
            DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders thirdPartySignalProviders) {
        this.thirdPartySignalProviders = thirdPartySignalProviders;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceAssuranceChromeOSPlatform deviceAssuranceChromeOSPlatform = (DeviceAssuranceChromeOSPlatform) o;
        return Objects.equals(this.thirdPartySignalProviders,
                deviceAssuranceChromeOSPlatform.thirdPartySignalProviders);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(thirdPartySignalProviders, super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceAssuranceChromeOSPlatform {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    thirdPartySignalProviders: ").append(toIndentedString(thirdPartySignalProviders)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/DeviceAssuranceChromeOSPlatform.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DeviceAssurance;
import com.okta.sdk.resource.model.DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders;
import com.okta.sdk.resource.model.LinksSelf;
import com.okta.sdk.resource.model.Platform;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DeviceAssuranceChromeOSPlatform
 */
@JsonPropertyOrder({ DeviceAssuranceChromeOSPlatform.JSON_PROPERTY_THIRD_PARTY_SIGNAL_PROVIDERS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "platform", visible = true, defaultImpl = DeviceAssuranceChromeOSPlatform.class)

public class DeviceAssuranceChromeOSPlatform extends DeviceAssurance implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_THIRD_PARTY_SIGNAL_PROVIDERS = "thirdPartySignalProviders";
    private DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders thirdPartySignalProviders;

    public DeviceAssuranceChromeOSPlatform() {
    }

    /*
     * @JsonCreator public DeviceAssuranceChromeOSPlatform(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED_BY) String createdBy,
     *
     * @JsonProperty(JSON_PROPERTY_CREATED_DATE) String createdDate,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATE) String lastUpdate,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED_BY) String lastUpdatedBy ) { this(); this.createdBy = createdBy;
     * this.createdDate = createdDate; this.id = id; this.lastUpdate = lastUpdate; this.lastUpdatedBy = lastUpdatedBy; }
     */

    public DeviceAssuranceChromeOSPlatform thirdPartySignalProviders(
            DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders thirdPartySignalProviders) {

        this.thirdPartySignalProviders = thirdPartySignalProviders;
        return this;
    }

    /**
     * Get thirdPartySignalProviders
     *
     * @return thirdPartySignalProviders
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_THIRD_PARTY_SIGNAL_PROVIDERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders getThirdPartySignalProviders() {
        return thirdPartySignalProviders;
    }

    @JsonProperty(JSON_PROPERTY_THIRD_PARTY_SIGNAL_PROVIDERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setThirdPartySignalProviders(
            DeviceAssuranceChromeOSPlatformAllOfThirdPartySignalProviders thirdPartySignalProviders) {
        this.thirdPartySignalProviders = thirdPartySignalProviders;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceAssuranceChromeOSPlatform deviceAssuranceChromeOSPlatform = (DeviceAssuranceChromeOSPlatform) o;
        return Objects.equals(this.thirdPartySignalProviders,
                deviceAssuranceChromeOSPlatform.thirdPartySignalProviders);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(thirdPartySignalProviders, super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceAssuranceChromeOSPlatform {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    thirdPartySignalProviders: ").append(toIndentedString(thirdPartySignalProviders)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
